@@ -192,7 +192,7 @@ aws <- function(y,
       # heteroskedastic Gaussian case
       zobj <- .Fortran(C_chaws,
         as.double(y),
-        as.logical(tobj$fix),
+        as.integer(tobj$fix),
         as.double(sigma2),
         as.integer(n1),
         as.integer(n2),
@@ -217,7 +217,7 @@ aws <- function(y,
       if (cpar$mcode != 6) {
         zobj <- .Fortran(C_caws,
           as.double(y),
-          as.logical(tobj$fix),
+          as.integer(tobj$fix),
           as.integer(n1),
           as.integer(n2),
           as.integer(n3),
@@ -238,7 +238,7 @@ aws <- function(y,
       } else {
         zobj <- .Fortran(C_caws6,
           as.double(y),
-          as.logical(tobj$fix),
+          as.integer(tobj$fix),
           as.integer(n1),
           as.integer(n2),
           as.integer(n3),
