@@ -140,7 +140,7 @@ aws.gaussian <- function(y,
     dlw <- (2 * trunc(hpre / c(1, wghts)) + 1)[1:d]
     hobj <- .Fortran(C_caws,
       as.double(y),
-      as.logical(tobj$fix),
+      as.integer(tobj$fix),
       as.integer(n1),
       as.integer(n2),
       as.integer(n3),
@@ -183,8 +183,8 @@ aws.gaussian <- function(y,
       # heteroskedastic Gaussian case
       zobj <- .Fortran(C_cgaws,
         as.double(y),
-        as.logical(tobj$fix),
-        as.logical(mask),
+        as.integer(tobj$fix),
+        as.integer(mask),
         as.double(sigma2),
         as.integer(n1),
         as.integer(n2),
