@@ -87,15 +87,15 @@ void F77_NAME(pawswght)(int* n1, int* n2, int* n3, int* i1, int* i2, int* i3,
   int* npsize, double* wi);
 void F77_NAME(pcaws)(double* y, int* n1, int* n2, int* n3,
   double* hakt, double* lambda, double* theta, double* bi,
-  double* bi2, double* bi0, double(bin), double* ai, int* model, int* kern,
+  double* bi2, double* bi0, double* bin, double* ai, int* model, int* kern,
   double* spmin, double* lwght, double* wght, int* npsize);
 void F77_NAME(pcaws2)(double* y, int* n1, int* n2, int* n3,
   double* hakt, double* lambda, double* theta, double* bi, double* bip,
-  double* bi2, double* bi0, double(bin), double* ai, int* model, int* kern,
+  double* bi2, double* bi0, double* bin, double* ai, int* model, int* kern,
   double* spmin, double* lwght, double* wght, int* npsize);
 void F77_NAME(pcaws3)(double* y, int* n1, int* n2, int* n3,
     double* hakt, double* lambda, double* theta, double* bi,
-    double* bi2, double* bi0, double(bin), double* ai, int* model, int* kern,
+    double* bi2, double* bi0, double* bin, double* ai, int* model, int* kern,
     double* spmin, double* lwght, double* wght, int* npsize, int* qind);
 void F77_NAME(pcawsm)(double* y, int* pos, int* n1, int* n2, int* n3,
   double* hakt, double* lambda, double* theta, double* bi,
@@ -134,23 +134,23 @@ void F77_NAME(fillpat3)(double* x, int* n1, int* n2, int* n3, int* phw,
   int* psize, double* pmat);
 void F77_NAME(nlmeans)(double* x, int* n1, int* n2, int* n3, double* patch,
   int* pd, int* swd, double* tau, double* xhat);
-static R_NativePrimitiveArgType awsph1_t[]={REALSXP, REALSXP, LGLSXP, INTSXP,
+static R_NativePrimitiveArgType awsph1_t[]={REALSXP, REALSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP};
-static R_NativePrimitiveArgType awsph2_t[]={REALSXP, REALSXP, LGLSXP, INTSXP,
+static R_NativePrimitiveArgType awsph2_t[]={REALSXP, REALSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, INTSXP, REALSXP, REALSXP,REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, REALSXP, INTSXP, REALSXP,REALSXP, REALSXP, REALSXP, REALSXP,
   INTSXP};
-static R_NativePrimitiveArgType awsp1b_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType awsp1b_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP};
-static R_NativePrimitiveArgType awsp2_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType awsp2_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP};
-static R_NativePrimitiveArgType caws_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType caws_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType cawsmask_t[]={REALSXP, LGLSXP, INTSXP, LGLSXP,
+static R_NativePrimitiveArgType cawsmask_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP};
 static R_NativePrimitiveArgType cawsw_t[]={INTSXP, INTSXP, INTSXP, REALSXP,
@@ -160,16 +160,16 @@ static R_NativePrimitiveArgType cawsw1_t[]={INTSXP, INTSXP, INTSXP, INTSXP,
   REALSXP, REALSXP, REALSXP};
 static R_NativePrimitiveArgType caws1_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType caws6_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType caws6_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType cgaws_t[]={REALSXP, LGLSXP, LGLSXP, REALSXP,
+static R_NativePrimitiveArgType cgaws_t[]={REALSXP, INTSXP, INTSXP, REALSXP,
   INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType cgawsmas_t[]={REALSXP, LGLSXP, INTSXP, LGLSXP,
+static R_NativePrimitiveArgType cgawsmas_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   REALSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType chaws_t[]={REALSXP, LGLSXP, REALSXP, INTSXP,
+static R_NativePrimitiveArgType chaws_t[]={REALSXP, INTSXP, REALSXP, INTSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP};
 static R_NativePrimitiveArgType chaws1_t[]={REALSXP, REALSXP, INTSXP, INTSXP,
@@ -178,13 +178,13 @@ static R_NativePrimitiveArgType chaws1_t[]={REALSXP, REALSXP, INTSXP, INTSXP,
 static R_NativePrimitiveArgType exceed_t[]={REALSXP, INTSXP, REALSXP, INTSXP,
   REALSXP};
 static R_NativePrimitiveArgType exceedm_t[]={REALSXP, INTSXP, REALSXP, INTSXP,
-  REALSXP, LGLSXP};
+  REALSXP, INTSXP};
 static R_NativePrimitiveArgType gethani_t[]={REALSXP, REALSXP, INTSXP,
   REALSXP, REALSXP, REALSXP, REALSXP};
 static R_NativePrimitiveArgType getvofh_t[]={REALSXP, INTSXP, REALSXP, REALSXP};
 static R_NativePrimitiveArgType lkern1_t[]={REALSXP, INTSXP, REALSXP, INTSXP,
   INTSXP, REALSXP};
-static R_NativePrimitiveArgType mask_t[]={LGLSXP, LGLSXP, INTSXP, INTSXP, INTSXP};
+static R_NativePrimitiveArgType mask_t[]={INTSXP, INTSXP, INTSXP, INTSXP, INTSXP};
 static R_NativePrimitiveArgType median1d_t[]={REALSXP, INTSXP, REALSXP};
 static R_NativePrimitiveArgType median2d_t[]={REALSXP, INTSXP, INTSXP, REALSXP};
 static R_NativePrimitiveArgType median3d_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
@@ -208,22 +208,22 @@ static R_NativePrimitiveArgType pcaws3_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
 static R_NativePrimitiveArgType pcawsm_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, INTSXP,
   REALSXP, REALSXP, REALSXP, INTSXP};
-static R_NativePrimitiveArgType pvaws_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType pvaws_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, REALSXP,
   REALSXP, REALSXP, REALSXP, INTSXP, INTSXP, INTSXP};
-static R_NativePrimitiveArgType pvaws2_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType pvaws2_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, INTSXP, INTSXP};
 static R_NativePrimitiveArgType sector_t[]={REALSXP, INTSXP, REALSXP, INTSXP,
-  INTSXP, INTSXP, LGLSXP, REALSXP};
-static R_NativePrimitiveArgType segment_t[]={REALSXP, LGLSXP, REALSXP, REALSXP,
+  INTSXP, INTSXP, INTSXP, REALSXP};
+static R_NativePrimitiveArgType segment_t[]={REALSXP, INTSXP, REALSXP, REALSXP,
   REALSXP, INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, INTSXP,
   INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType vaws_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType vaws_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP,
   REALSXP, REALSXP, REALSXP, REALSXP};
-static R_NativePrimitiveArgType vaws2_t[]={REALSXP, LGLSXP, INTSXP, INTSXP,
+static R_NativePrimitiveArgType vaws2_t[]={REALSXP, INTSXP, INTSXP, INTSXP,
   INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
   REALSXP};
